/* Copyright (c) 2014 Nordic Semiconductor. All Rights Reserved.
 *
 * The information contained herein is property of Nordic Semiconductor ASA.
 * Terms and conditions of usage are described in detail in NORDIC
 * SEMICONDUCTOR STANDARD SOFTWARE LICENSE AGREEMENT.
 *
 * Licensees are granted free, non-transferable use of the information. NO
 * WARRANTY of ANY KIND is provided. This heading must NOT be removed from
 * the file.
 *
 */

/** @file
 *
 * @defgroup ble_sdk_app_beacon_main main.c
 * @{
 * @ingroup ble_sdk_app_beacon
 * @brief Beacon Transmitter Sample Application main file.
 *
 * This file contains the source code for an Beacon transmitter sample application.
 */

#include <stdbool.h>
#include <stdint.h>
#include "ble_advdata.h"
#include "nordic_common.h"
#include "softdevice_handler.h"
#include "bsp.h"
#include "app_timer2.h"
#include "nrf_delay.h"
#include "app_util_platform.h"
#include "app_uart.h"
#include "nrf_drv_twi.h"
#include "nrf_drv_config.h"

#define ts 		3
#define tm 		20 
#define calc 	1
//____________________________________________________________
#include "ble_advertising.h"
#include "pstorage.h"
#include "nrf_assert.h"

#define IS_SRVC_CHANGED_CHARACT_PRESENT 0                                 /**< Include or not the service_changed characteristic. if not enabled, the server's database cannot be changed for the lifetime of the device*/

#define APP_CFG_NON_CONN_ADV_TIMEOUT    0                                 /**< Time for which the device must be advertising in non-connectable mode (in seconds). 0 disables timeout. */
#define NON_CONNECTABLE_ADV_INTERVAL    MSEC_TO_UNITS(200, UNIT_0_625_MS) /**< The advertising interval for non-connectable advertisement (100 ms). This value can vary between 100ms to 10.24s). */

#define DEAD_BEEF                       0xDEADBEEF                        /**< Value used as error code on stack dump, can be used to identify stack location on stack unwind. */

#define APP_TIMER_PRESCALER             0                                 /**< Value of the RTC1 PRESCALER register. */
#define APP_TIMER_MAX_TIMERS            (2+BSP_APP_TIMERS_NUMBER)         /**< Maximum number of simultaneously created timers. */
#define APP_TIMER_OP_QUEUE_SIZE         4                                 /**< Size of timer operation queues. */

#if defined(USE_UICR_FOR_MAJ_MIN_VALUES)
#define MAJ_VAL_OFFSET_IN_BEACON_INFO   18                                /**< Position of the MSB of the Major Value in m_beacon_info array. */
#define UICR_ADDRESS                    0x10001080                        /**< Address of the UICR register used by this example. The major and minor versions to be encoded into the advertising data will be picked up from this location. */
#endif

float nom, denom, fe_ave;
float fe[105];
uint8_t 	session_closed;
//_____________________________________________________________________________________________________________
/**@brief Global variables used for storing assert information from the SoftDevice.
 */
static uint32_t g_sd_assert_line_num;
static uint32_t g_sd_assert_pc;
static uint8_t  g_sd_assert_file_name[100];

/**@brief Global variables used for storing assert information from the nRF51 SDK.
 */
static uint32_t g_nrf_assert_line_num;
static uint8_t  g_nrf_assert_file_name[100];

/**@brief Callback handlers
 */
static void sd_assert_cb(uint32_t pc, uint16_t line_num, const uint8_t *file_name);

/**@brief Assert callback handler for SoftDevice asserts. */
void sd_assert_cb (uint32_t pc, uint16_t line_num, const uint8_t *file_name)
{
  g_sd_assert_line_num = line_num;
  g_sd_assert_pc = pc;
  memset ((void*)g_sd_assert_file_name, 0x00, sizeof(g_sd_assert_file_name));
  (void) strncpy ((char*) g_sd_assert_file_name, (const char*) file_name, sizeof(g_sd_assert_file_name) - 1);

  while(1);
}

/**@brief Function for doing power management.
 */
static void power_manage(void)
{
    uint32_t err_code = sd_app_evt_wait();
    APP_ERROR_CHECK(err_code);
}
//_____________________________________________________________________________________________________________

/**
 * @brief Function for application main entry.
 */
int main(void)
{
	
  uint8_t err_code = NRF_SUCCESS;
  err_code = sd_softdevice_enable ((uint32_t) NRF_CLOCK_LFCLKSRC_XTAL_20_PPM, sd_assert_cb);
	ASSERT (err_code == NRF_SUCCESS);
	

	/*---------------------------------------------------------------------------*/
	/*                          Loop For Measuring Current                       */
	/*---------------------------------------------------------------------------*/
	
	uint8_t no_p= 8;
	//----------------------------------------------------------------------------
	int32_t cS[8] = {0x0325, 0x0327, 0x0320, 0x0322, 0x0323, 0x0321, 0x0327, 0x0324};
	int32_t tS[8] = {0x184A, 0x2906, 0x2CF2, 0x3EB3, 0x308C, 0x0EBF, 0x090B, 0x0072};
	
	int32_t cM[8] = {0x0325, 0x0327, 0x0320, 0x0322, 0x0323, 0x0321, 0x0327, 0x0323};
	int32_t tM[8] = {0x17C1, 0x287E, 0x2C6A, 0x3E2B, 0x3004, 0x0E38, 0x0882, 0x4E09};
	
  for (;; )
  {

		fe_ave=0; nom=0; denom=0;
		
		for (uint8_t i=1;i<=no_p;i++) 
		{	
			nom = (float) ((cS[i]-cM[i])*20000 + (tS[i]-tM[i]));
			denom = (float) (cM[i]*20000 + tM[i]);
			fe[i] = nom / denom;
											
			fe_ave = fe_ave + fe[i]; 
		}
		
		fe_ave = fe_ave /no_p;
		
  }
	
}
